==> ejc-supbid-impl-3.0.1-20220106.092544-103-sources.jar: com/ejianc/business/supbid/notice/service/INoticeService.java <==
package com.ejianc.business.supbid.notice.service;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.supbid.notice.bean.NoticeEntity;
import com.ejianc.business.supbid.notice.vo.NoticeVO;
import com.ejianc.business.supbid.notice.vo.NumsVO;
import com.ejianc.business.supbid.notice.vo.SupOfferVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.template.IBaseService;
import org.apache.http.HttpRequest;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * 公告实体
 * 
 * @author generator
 * 
 */
public interface INoticeService extends IBaseService<NoticeEntity> {

    CommonResponse<Boolean> save(NoticeVO saveorUpdateVO);

    CommonResponse<Boolean> saveWj(HttpServletRequest request,MultipartFile file);

    CommonResponse<Boolean> addFile(HttpServletRequest request,MultipartFile file);

    CommonResponse<String> delFile(String sourceId,List<String> fileNames);
    CommonResponse<NoticeVO> saveFile(NoticeVO saveorUpdateVO) throws Exception;

    CommonResponse<Boolean> updateTime(NoticeVO saveorUpdateVO);

    Boolean updateSupOffer(List<SupOfferVO> vos);

    NoticeVO queryDetail(Long id);

    NoticeVO queryFileDetail(Long id);

    List<NoticeVO> queryInvitationList(QueryWrapper queryWrapper,Integer tenderType,String tenantId);

    List<NoticeVO> queryAllList(QueryWrapper queryWrapper,String tenantId);

    NumsVO queryCounts();
}

==> ejc-supbid-impl-3.0.1-20220124.080804-130-sources.jar: com/ejianc/business/supbid/notice/service/INoticeService.java <==
package com.ejianc.business.supbid.notice.service;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ejianc.business.supbid.notice.bean.NoticeEntity;
import com.ejianc.business.supbid.notice.vo.NoticeVO;
import com.ejianc.business.supbid.notice.vo.NumsVO;
import com.ejianc.business.supbid.notice.vo.SupOfferVO;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.skeleton.template.IBaseService;
import org.apache.http.HttpRequest;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * 公告实体
 * 
 * @author generator
 * 
 */
public interface INoticeService extends IBaseService<NoticeEntity> {

    CommonResponse<Boolean> save(NoticeVO saveorUpdateVO);

    CommonResponse<Boolean> saveWj(HttpServletRequest request,MultipartFile file);

    CommonResponse<Boolean> addFile(HttpServletRequest request,MultipartFile file);

    CommonResponse<String> delFile(String sourceId,List<String> fileNames);
    CommonResponse<NoticeVO> saveFile(NoticeVO saveorUpdateVO) throws Exception;

    CommonResponse<Boolean> updateTime(NoticeVO saveorUpdateVO);

    Boolean updateSupOffer(List<SupOfferVO> vos);

    NoticeVO queryDetail(Long id);

    NoticeVO queryFileDetail(Long id);

    List<NoticeVO> queryInvitationList(QueryWrapper queryWrapper,Integer tenderType,String tenantId);

    List<NoticeVO> queryAllList(QueryWrapper queryWrapper,String tenantId);

    /**
     * 查询供方门户招标列表数据
     * @param param 查询参数
     * @return 查询结果
     */
    IPage<NoticeVO> queryHomeList(QueryParam param);

    NumsVO queryCounts();
}
